<?php
/**
 * Plugin Name: WP Revision Cleaner
 * Plugin URI: https://example.com/plugins/wp-revision-cleaner
 * Description: WordPressの古いリビジョンを自動的に整理し、一週間以上前のリビジョンは1日あたり1つのみ保持します。実行状況の表示機能付き。
 * Version: 1.0.0
 * Author: Your Name
 * Author URI: https://example.com
 * License: GPL2
 * Text Domain: wp-revision-cleaner
 * Domain Path: /languages
 */

// 直接アクセス禁止
if (!defined('ABSPATH')) {
    exit;
}

// プラグインのパスとURLを定義
define('WP_REVISION_CLEANER_PATH', plugin_dir_path(__FILE__));
define('WP_REVISION_CLEANER_URL', plugin_dir_url(__FILE__));
define('WP_REVISION_CLEANER_VERSION', '1.0.0');

// 削除履歴を保存するオプション名
define('REVISION_CLEANUP_LOG', 'revision_cleanup_history');

// プラグインのクラスファイルを読み込み
require_once WP_REVISION_CLEANER_PATH . 'includes/class-revision-cleaner.php';
require_once WP_REVISION_CLEANER_PATH . 'admin/class-admin-page.php';

// プラグインのインスタンスをグローバル変数に保存
global $wp_revision_cleaner;

// プラグインのインスタンスを初期化
function wp_revision_cleaner_init() {
    global $wp_revision_cleaner;
    
    // クリーナークラスのインスタンス化
    $wp_revision_cleaner = new WP_Revision_Cleaner();
    $wp_revision_cleaner->setup();
    
    // 管理画面が有効な場合のみ管理ページを読み込む
    if (is_admin()) {
        $admin_page = new WP_Revision_Cleaner_Admin();
        $admin_page->setup();
    }
}
add_action('plugins_loaded', 'wp_revision_cleaner_init');

// プラグイン有効化時の処理
register_activation_hook(__FILE__, 'wp_revision_cleaner_activate');
function wp_revision_cleaner_activate() {
    // 初回のスケジュール設定
    if (!wp_next_scheduled('daily_revision_cleanup')) {
        // 次の3:00AMに設定
        $timestamp = strtotime('tomorrow 3:00am');
        if (time() < strtotime('today 3:00am')) {
            $timestamp = strtotime('today 3:00am');
        }
        wp_schedule_event($timestamp, 'daily', 'daily_revision_cleanup');
    }
    
    // デフォルトの処理状況を初期化
    update_option('wp_revision_cleaner_status', array(
        'running' => false,
        'total' => 0,
        'processed' => 0,
        'deleted' => 0,
        'preserved' => 0,
        'start_time' => 0,
        'last_update' => 0,
        'current_action' => '',
        'recent_items' => array()
    ));
    
    // 有効化メッセージをオプションに保存
    add_option('wp_revision_cleaner_activated', true);
}

// プラグイン無効化時の処理
register_deactivation_hook(__FILE__, 'wp_revision_cleaner_deactivate');
function wp_revision_cleaner_deactivate() {
    // スケジュールを解除
    wp_clear_scheduled_hook('daily_revision_cleanup');
    wp_clear_scheduled_hook('wp_revision_cleaner_background_process');
}

// アンインストール時の処理
register_uninstall_hook(__FILE__, 'wp_revision_cleaner_uninstall');
function wp_revision_cleaner_uninstall() {
    // オプションを削除
    delete_option(REVISION_CLEANUP_LOG);
    delete_option('wp_revision_cleaner_activated');
    delete_option('wp_revision_cleaner_status');
}